@@ -1,7 +1,3 @@
-.onLoad <- function(lib, pkg) {
-	library.dynam("hmm.discnp", pkg, lib)
-}
-
 .onAttach <- function(lib, pkg) {
 	ver <- read.dcf(file.path(lib, pkg, "DESCRIPTION"), "Version")
         packageStartupMessage(paste(pkg, ver))
